@@ -8,10 +8,10 @@ use warnings;
 
 use Cv::Seq;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 our @ISA = qw(Cv::Seq);
 
-# { no strict 'refs'; *AUTOLOAD = \&Cv::autoload; }
+{ no strict 'refs'; *AUTOLOAD = \&Cv::autoload; }
 
 sub new {
 	my $self = shift;
